# optimal-loc
A python project which finds the optimal N locations in a given area according to the given location inputs.

### Purpose of the Package
+ dsd
+ dsds

### Features


### Getting Started
+ Package can be found on pypi hence you can install it using pip.

### Installation
```bash
pip install optimal_loc
```

### Usage
```bash
from optimal_loc import return_message
output = return_message(my_input=5) # 50
```

### Contribution
Contributions are welcome.
Notice a bug let us know.

### Author
+ Main Maintainer: Sinan Demirhan (SDemirhan)